==> ubi_0.9.2-1.tar.gz: ubi-0.9.2/translations/ubi.pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>AccountPage</name>
    <message>
        <source>Authorization failed!</source>
        <translation>Autoryzacja nie powiodła się!</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>User name:</source>
        <translation>Nazwa użytkownika:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>Email:</translation>
    </message>
    <message>
        <source>Total storage:</source>
        <translation>Całkowita pojemność:</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Unable to connect!</source>
        <translation>Błąd połączenia!</translation>
    </message>
    <message>
        <source>Used:</source>
        <translation>Wykorzystano:</translation>
    </message>
</context>
<context>
    <name>DialogYesNo</name>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
</context>
<context>
    <name>DownloadArea</name>
    <message>
        <source>No active downloads</source>
        <translation>Brak aktywnych pobrań</translation>
    </message>
</context>
<context>
    <name>FilesPage</name>
    <message>
        <source>Upload file</source>
        <translation>Wyślij nowy plik</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>New folder</source>
        <translation>Nowy folder</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <source>Root folder can&apos;t be renamed!</source>
        <translation>Nie można zmienić nazwy!</translation>
    </message>
    <message>
        <source>Root folder can&apos;t be deleted!</source>
        <translation>Nie można zmienić nazwy!</translation>
    </message>
    <message>
        <source>Authorization failed!</source>
        <translation>Autoryzacja nie powiodła się!</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>Folder renamed!</source>
        <translation>Zmieniono nazwę!</translation>
    </message>
    <message>
        <source>New folder created!</source>
        <translation>Utworzono folder!</translation>
    </message>
    <message>
        <source>Folder was deleted!</source>
        <translation>Usunięto folder!</translation>
    </message>
    <message>
        <source>Delete folder?</source>
        <translation>Czy usunąć folder?</translation>
    </message>
    <message>
        <source>Enter new folder name...</source>
        <translation type="obsolete">Podaj nową nazwę folderu...</translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>Nieprawidłowa nazwa folderu!</translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Pliki</translation>
    </message>
    <message>
        <source>Unable to connect!</source>
        <translation>Błąd połączenia!</translation>
    </message>
    <message>
        <source>Enter new folder name:</source>
        <translation>Podaj nową nazwę folderu:</translation>
    </message>
    <message>
        <source>Folder is empty.</source>
        <translation type="obsolete">Folder jest pusty.</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Pusty</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>User ID</source>
        <translation>ID użytkownika</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Logged in!</source>
        <translation>Zalogowany!</translation>
    </message>
    <message>
        <source>Authorization failed!</source>
        <translation>Autoryzacja nie powiodła się!</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Logowanie</translation>
    </message>
    <message>
        <source>Ubuntu One sign in:</source>
        <translation>Zaloguj się do Ubuntu One:</translation>
    </message>
    <message>
        <source>Unable to connect!</source>
        <translation>Błąd połączenia!</translation>
    </message>
</context>
<context>
    <name>PropertiesPage</name>
    <message>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Authorization failed!</source>
        <translation>Autoryzacja nie powiodła się!</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>Internal error!</source>
        <translation>Błąd wewnętrzny!</translation>
    </message>
    <message>
        <source>File renamed!</source>
        <translation>Zmieniono nazwę!</translation>
    </message>
    <message>
        <source>File name:</source>
        <translation>Nazwa pliku:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Rozmiar:</translation>
    </message>
    <message>
        <source>Created:</source>
        <translation>Utworzono:</translation>
    </message>
    <message>
        <source>Changed:</source>
        <translation>Zmieniono:</translation>
    </message>
    <message>
        <source>Delete file?</source>
        <translation>Czy usunąć plik?</translation>
    </message>
    <message>
        <source>Enter new file name...</source>
        <translation type="obsolete">Podaj nową nazwę pliku...</translation>
    </message>
    <message>
        <source>Invalid file name!</source>
        <translation>Nieprawidłowa nazwa pliku!</translation>
    </message>
    <message>
        <source>File deleted!</source>
        <translation>Usunięto plik!</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <source>Unable to connect!</source>
        <translation>Błąd połączenia!</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Podaj nową nazwę pliku:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation>Upublicznij</translation>
    </message>
    <message>
        <source>Publishing stopped!</source>
        <translation>Upublicznianie wyłączone!</translation>
    </message>
    <message>
        <source>Publishing started!</source>
        <translation>Upublicznianie włączone!</translation>
    </message>
    <message>
        <source>Public URL:</source>
        <translation>Publiczny URL:</translation>
    </message>
    <message>
        <source>Public URL copied to clipboard!</source>
        <translation>Publiczny URL skopiowany!</translation>
    </message>
    <message>
        <source>Stop publishing?</source>
        <translation>Wyłączyć upublicznianie?</translation>
    </message>
    <message>
        <source>Start publishing?</source>
        <translation>Włączyć upublicznianie?</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Skopiuj</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation type="obsolete">Polski</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Angielski</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Język:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Zmień</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Logged as:</source>
        <translation>Zalogowany jako:</translation>
    </message>
    <message>
        <source>Restart application!</source>
        <translation>Zrestartuj aplikacje!</translation>
    </message>
    <message>
        <source>Choose language:</source>
        <translation>Wybierz język:</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>About Ubi</source>
        <translation>O Ubi</translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Pliki</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Ubuntu One client for Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;</source>
        <translation type="obsolete">&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Apliacja do zarządzania usługą Ubuntu One w systemie Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michał Kościesza&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Ubuntu One client for Maemo5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;</source>
        <translation type="obsolete">&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Aplikacja Ubuntu One dla Maemo5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Ubuntu One client for Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;&lt;br/&gt;</source>
        <translation type="obsolete">&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Aplikacja Ubuntu One dla Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Ubi&lt;/b&gt; 0.9.1&lt;br/&gt;Ubuntu One client for Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;&lt;br/&gt;</source>
        <translation type="obsolete">&lt;b&gt;Ubi&lt;/b&gt; 0.9.1&lt;br/&gt;Aplikacja Ubuntu One dla Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;&lt;br/&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Ubi&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ubi&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;An unofficial Ubuntu One app for Maemo 5 and other Qt-enabled platforms.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Nieoficjalna aplikacja Ubuntu One dla Maemo 5 i innych platform obsługujących Qt.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Error while downloading!</source>
        <translation>Błąd podczas pobierania!</translation>
    </message>
    <message>
        <source>Error while uploading!</source>
        <translation>Błąd podczas wysyłania!</translation>
    </message>
    <message>
        <source>File downloaded!</source>
        <translation>Plik został pobrany!</translation>
    </message>
    <message>
        <source>File uploaded!</source>
        <translation>Plik został wysłany!</translation>
    </message>
    <message>
        <source>File added to the queue!</source>
        <translation>Plik dodany do kolejki!</translation>
    </message>
</context>
</TS>

==> ubi_0.9.3-2.tar.gz: ubi-0.9.3/translations/ubi.pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>AccountPage</name>
    <message>
        <source>Authorization failed!</source>
        <translation type="obsolete">Autoryzacja nie powiodła się!</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation type="obsolete">Błąd:</translation>
    </message>
    <message>
        <source>User name:</source>
        <translation>Nazwa użytkownika:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>Email:</translation>
    </message>
    <message>
        <source>Total storage:</source>
        <translation>Całkowita pojemność:</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Unable to connect!</source>
        <translation type="obsolete">Błąd połączenia!</translation>
    </message>
    <message>
        <source>Used:</source>
        <translation>Wykorzystano:</translation>
    </message>
    <message>
        <source>Ubuntu One authorization has failed. Try once again or check login settings.</source>
        <translation>Autoryzacja w Ubuntu One nie powiodła się. Spróbuj jeszcze raz lub sprawdź ustawienia logowania.</translation>
    </message>
    <message>
        <source>Unable to connect. Check internet connection.</source>
        <translation>Nie można połączyć z siecią. Sprawadź połączenie z Internetem.</translation>
    </message>
    <message>
        <source>Unknown error: </source>
        <translation>Nieznany błąd:</translation>
    </message>
</context>
<context>
    <name>DialogYesNo</name>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
</context>
<context>
    <name>DownloadArea</name>
    <message>
        <source>No active downloads</source>
        <translation type="obsolete">Brak aktywnych pobrań</translation>
    </message>
    <message>
        <source>No active downloads or uploads</source>
        <translation>Brak aktywnych pobrań</translation>
    </message>
    <message>
        <source>Active downloads and uploads</source>
        <translation>Aktywne pobrania</translation>
    </message>
</context>
<context>
    <name>FilesPage</name>
    <message>
        <source>Upload file</source>
        <translation>Wyślij nowy plik</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>New folder</source>
        <translation>Nowy folder</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <source>Root folder can&apos;t be renamed!</source>
        <translation type="obsolete">Nie można zmienić nazwy!</translation>
    </message>
    <message>
        <source>Root folder can&apos;t be deleted!</source>
        <translation type="obsolete">Nie można zmienić nazwy!</translation>
    </message>
    <message>
        <source>Authorization failed!</source>
        <translation>Autoryzacja nie powiodła się!</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>Folder renamed!</source>
        <translation>Zmieniono nazwę!</translation>
    </message>
    <message>
        <source>New folder created!</source>
        <translation>Utworzono folder!</translation>
    </message>
    <message>
        <source>Folder was deleted!</source>
        <translation>Usunięto folder!</translation>
    </message>
    <message>
        <source>Delete folder?</source>
        <translation>Czy usunąć folder?</translation>
    </message>
    <message>
        <source>Enter new folder name...</source>
        <translation type="obsolete">Podaj nową nazwę folderu...</translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>Nieprawidłowa nazwa folderu!</translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Pliki</translation>
    </message>
    <message>
        <source>Unable to connect!</source>
        <translation type="obsolete">Błąd połączenia!</translation>
    </message>
    <message>
        <source>Enter new folder name:</source>
        <translation>Podaj nową nazwę folderu:</translation>
    </message>
    <message>
        <source>Folder is empty.</source>
        <translation type="obsolete">Folder jest pusty.</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Pusty</translation>
    </message>
    <message>
        <source>Root folder cannot be renamed.</source>
        <translation>Nie można zmienić nazwy głównego foldera.</translation>
    </message>
    <message>
        <source>Root folder cannot be deleted.</source>
        <translation>Nie można usunąć głównego foldera.</translation>
    </message>
    <message>
        <source>Ubuntu One authorization has failed. Try once again or check login settings.</source>
        <translation>Autoryzacja w Ubuntu One nie powiodła się. Spróbuj jeszcze raz lub sprawdź ustawienia logowania.</translation>
    </message>
    <message>
        <source>Unable to connect. Check internet connection.</source>
        <translation>Nie można połączyć z siecią. Sprawadź połączenie z Internetem.</translation>
    </message>
    <message>
        <source>Unknown error: </source>
        <translation>Nieznany błąd:</translation>
    </message>
</context>
<context>
    <name>InitPage</name>
    <message>
        <source>Ubuntu One authorization has failed. Try once again or check login settings.</source>
        <translation>Autoryzacja w Ubuntu One nie powiodła się. Spróbuj jeszcze raz lub sprawdź ustawienia logowania.</translation>
    </message>
    <message>
        <source>Unable to connect. Check internet connection.</source>
        <translation>Nie można połączyć z siecią. Sprawadź połączenie z Internetem.</translation>
    </message>
    <message>
        <source>Unknown error: </source>
        <translation>Nieznany błąd:</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Łączenie...</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>User ID</source>
        <translation>ID użytkownika</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Logged in!</source>
        <translation>Zalogowany!</translation>
    </message>
    <message>
        <source>Authorization failed!</source>
        <translation type="obsolete">Autoryzacja nie powiodła się!</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation type="obsolete">Błąd:</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Logowanie</translation>
    </message>
    <message>
        <source>Ubuntu One sign in:</source>
        <translation>Zaloguj się do Ubuntu One:</translation>
    </message>
    <message>
        <source>Unable to connect!</source>
        <translation type="obsolete">Błąd połączenia!</translation>
    </message>
    <message>
        <source>Ubuntu One authorization has failed. Try once again or check login settings.</source>
        <translation>Autoryzacja w Ubuntu One nie powiodła się. Spróbuj jeszcze raz lub sprawdź ustawienia logowania.</translation>
    </message>
    <message>
        <source>Unable to connect. Check internet connection.</source>
        <translation>Nie można połączyć z siecią. Sprawadź połączenie z Internetem.</translation>
    </message>
    <message>
        <source>Unknown error: </source>
        <translation>Nieznany błąd:</translation>
    </message>
</context>
<context>
    <name>PropertiesPage</name>
    <message>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Authorization failed!</source>
        <translation type="obsolete">Autoryzacja nie powiodła się!</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation type="obsolete">Błąd:</translation>
    </message>
    <message>
        <source>Internal error!</source>
        <translation>Błąd wewnętrzny!</translation>
    </message>
    <message>
        <source>File renamed!</source>
        <translation>Zmieniono nazwę!</translation>
    </message>
    <message>
        <source>File name:</source>
        <translation>Nazwa pliku:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Rozmiar:</translation>
    </message>
    <message>
        <source>Created:</source>
        <translation>Utworzono:</translation>
    </message>
    <message>
        <source>Changed:</source>
        <translation>Zmieniono:</translation>
    </message>
    <message>
        <source>Delete file?</source>
        <translation>Czy usunąć plik?</translation>
    </message>
    <message>
        <source>Enter new file name...</source>
        <translation type="obsolete">Podaj nową nazwę pliku...</translation>
    </message>
    <message>
        <source>Invalid file name!</source>
        <translation>Nieprawidłowa nazwa pliku!</translation>
    </message>
    <message>
        <source>File deleted!</source>
        <translation>Usunięto plik!</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <source>Unable to connect!</source>
        <translation type="obsolete">Błąd połączenia!</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Podaj nową nazwę pliku:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation>Upublicznij</translation>
    </message>
    <message>
        <source>Publishing stopped!</source>
        <translation>Upublicznianie wyłączone!</translation>
    </message>
    <message>
        <source>Publishing started!</source>
        <translation>Upublicznianie włączone!</translation>
    </message>
    <message>
        <source>Public URL:</source>
        <translation>Publiczny URL:</translation>
    </message>
    <message>
        <source>Public URL copied to clipboard!</source>
        <translation>Publiczny URL skopiowany!</translation>
    </message>
    <message>
        <source>Stop publishing?</source>
        <translation>Wyłączyć upublicznianie?</translation>
    </message>
    <message>
        <source>Start publishing?</source>
        <translation>Włączyć upublicznianie?</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Skopiuj</translation>
    </message>
    <message>
        <source>Ubuntu One authorization has failed. Try once again or check login settings.</source>
        <translation>Autoryzacja w Ubuntu One nie powiodła się. Spróbuj jeszcze raz lub sprawdź ustawienia logowania.</translation>
    </message>
    <message>
        <source>Unknown error: </source>
        <translation>Nieznany błąd:</translation>
    </message>
    <message>
        <source>Unable to connect. Check internet connection.</source>
        <translation>Nie można połączyć z siecią. Sprawadź połączenie z Internetem.</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation type="obsolete">Polski</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Angielski</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Język:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Zmień</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Logged as:</source>
        <translation>Zalogowany jako:</translation>
    </message>
    <message>
        <source>Restart application!</source>
        <translation>Zrestartuj aplikacje!</translation>
    </message>
    <message>
        <source>Choose language:</source>
        <translation>Wybierz język:</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>About Ubi</source>
        <translation>O Ubi</translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Pliki</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Ubuntu One client for Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;</source>
        <translation type="obsolete">&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Apliacja do zarządzania usługą Ubuntu One w systemie Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michał Kościesza&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Ubuntu One client for Maemo5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;</source>
        <translation type="obsolete">&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Aplikacja Ubuntu One dla Maemo5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Ubuntu One client for Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;&lt;br/&gt;</source>
        <translation type="obsolete">&lt;b&gt;Ubi&lt;/b&gt; 1.0.0&lt;br/&gt;Aplikacja Ubuntu One dla Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Ubi&lt;/b&gt; 0.9.1&lt;br/&gt;Ubuntu One client for Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;&lt;br/&gt;</source>
        <translation type="obsolete">&lt;b&gt;Ubi&lt;/b&gt; 0.9.1&lt;br/&gt;Aplikacja Ubuntu One dla Maemo 5&lt;br/&gt;&lt;small&gt;Copyright © 2012 Michal Kosciesza&lt;/small&gt;&lt;br/&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Ubi&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ubi&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;An unofficial Ubuntu One app for Maemo 5 and other Qt-enabled platforms.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Nieoficjalna aplikacja Ubuntu One dla Maemo 5 i innych platform obsługujących Qt.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>TaskMenu</name>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>About Ubi</source>
        <translation>O Ubi</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Error while downloading!</source>
        <translation type="obsolete">Błąd podczas pobierania!</translation>
    </message>
    <message>
        <source>Error while uploading!</source>
        <translation type="obsolete">Błąd podczas wysyłania!</translation>
    </message>
    <message>
        <source>File downloaded!</source>
        <translation type="obsolete">Plik został pobrany!</translation>
    </message>
    <message>
        <source>File uploaded!</source>
        <translation type="obsolete">Plik został wysłany!</translation>
    </message>
    <message>
        <source>File added to the queue!</source>
        <translation type="obsolete">Plik dodany do kolejki!</translation>
    </message>
    <message>
        <source>File operation canceled!</source>
        <translation type="obsolete">Operacja anulowana!</translation>
    </message>
    <message>
        <source>&lt;b&gt;Ubi&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ubi&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;An unofficial Ubuntu One app for Maemo 5 and other Qt-enabled platforms.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Nieoficjalna aplikacja Ubuntu One dla Maemo 5 i innych platform obsługujących Qt.&lt;/p&gt;&lt;p&gt;&lt;small&gt;http://ubi.garage.maemo.org&lt;/small&gt;&lt;/p&gt;&lt;p&gt;&lt;small&gt;© 2012 Michal Kosciesza&lt;/small&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <source>File downloaded.</source>
        <translation>Plik został pobrany.</translation>
    </message>
    <message>
        <source>File uploaded.</source>
        <translation>Plik został wysłany.</translation>
    </message>
    <message>
        <source>Error while downloading.</source>
        <translation>Błąd podczas pobierania.</translation>
    </message>
    <message>
        <source>Error while uploading.</source>
        <translation>Błąd podczas wysyłania.</translation>
    </message>
    <message>
        <source>File added to the queue.</source>
        <translation>Plik dodany do kolejki.</translation>
    </message>
    <message>
        <source>File operation canceled.</source>
        <translation>Operacja anulowana.</translation>
    </message>
</context>
</TS>
